Accelerating Barnes-Hut t-SNE Algorithm by Efficient Parallelization on Multi-Core CPUs
Not on the map. Why?
Abstract (arXiv)
t-SNE remains one of the most popular embedding techniques for visualizing high-dimensional data. Most standard packages of t-SNE, such as scikit-learn, use the Barnes-Hut t-SNE (BH t-SNE) algorithm for large datasets. However, existing CPU implementations of this algorithm are inefficient. In this work, we accelerate the BH t-SNE on CPUs via cache optimizations, SIMD, parallelizing sequential steps, and improving parallelization of multithreaded steps. Our implementation (Acc-t-SNE) is up to 261x and 4x faster than scikit-learn and the state-of-the-art BH t-SNE implementation from daal4py, respectively, on a 32-core Intel(R) Icelake cloud instance.
Key facts. No citing papers in the map yet (data through 13 Oct 2026). Builds on 4 of its 22 references that are in the map. First posted on arXiv 22 Dec 2022.
Builds on
4 of 22 references.
References · 4
- 2017Fashion-MNIST: a Novel Image Dataset for Benchmarking Machine Learning Algorithmscited by 4,328
- 2018UMAP: Uniform Manifold Approximation and Projection for Dimension Reductioncited by 2,870
- 2017Efficient Algorithms for t-distributed Stochastic Neighborhood Embeddingcited by 75
- 2018t-SNE-CUDA: GPU-Accelerated t-SNE and its Applications to Modern Datacited by 19
Built on by
Not cited yet.